#!/bin/bash

if [[ -z "$1" ]]; then
	echo "Missing argument: Company ID"
	exit 1
fi

# Check if netcat supports options
nc -h > /dev/null 2>&1
if (( $? != 0 )); then
	# Send command without expecting return message
	echo -en "CMD apiclient \"register $1\"\r\n" | nc localhost 9240 > /dev/null 2>&1
	echo "Register command has been sent"
	exit 0
fi

# We run a full version of netcat, so we can check if the agent is running or
# wait for command ouput

# Test if agent is running
nc -z -v -w1 localhost 9240 > /dev/null 2>&1
if (( $? != 0 )); then
	echo "Agent isn't running"
	exit 1
fi

echo "Sending register command... "
RESULT=$(echo -en "CMD apiclient \"register $1\"\r\n" | nc -w2 localhost 9240)

if [[ ${RESULT} == *"3=Already registered"* ]]; then
	echo "Agent has already been registered"
	exit 1
elif [[ ${RESULT} == *"1=Invalid parameter company ID"* ]]; then
	echo "Invalid company ID"
	exit 1
elif [[ ${RESULT} == *"110 \"apiclient\" \"registered\""* ]]; then
	echo "The agent has been registered"
	exit 0
fi

echo "Failed to register agent"

exit 1
